# Change the content according to your package.
# from directory.filename.py import classname
from wfdanielpackagetest.dani import Dani
from wfdanielpackagetest.dani2 import Dani2
# from qafunnypet import Qafunnypet

__author__ = 'D.Mendez'
__email__ = 'pablomen1131@gmail.com'
__version__ = '0.2.4'

# module level doc-string
__doc__ = """
wfdanielpackagetest
================

Description
-----------
wfdanielpackagetest is a Python package created for demonstration purposes.
This information will show up when using the help function.

Example
-------
>>> # Import library
>>> from wfdanielpackagetest import Wfdanielpackagetest
>>> # Initialize
>>> model = Wfdanielpackagetest(message='Daniel')
>>> # Run the model
>>> model.show()

References
----------
* https://towardsdatascience.com/a-step-by-step-guide-in-detecting-causal-relationships-using-bayesian-structure-learning-in-python-c20c6b31cee5

"""



import logging

class Dani:

    def __init__(self, name=None):
        self.name = name
        if name is None:
            print("Why you dont want to tell me your name?")
        else:
            print(f"Hi dumb {self.name}")

    def use_loggin(self):
        if self.name is None:
            logging.warning(f"Youre logged but i dont know you")
        else:
            logging.warning(f"Youre logged {self.name}")

    def tell(self):
        if self.name is None:
            print("I dont know you dude, forget about")
        else:
            print(f"Hey {self.name} you are really cool")
